@@ -25,7 +25,10 @@ this program; if not, write to the Free Software Foundation, Inc.,
 '''
 
 import sys
-from gammu.Data import Connections, MemoryValueTypes, CalendarTypes, CalendarValueTypes, TodoPriorities, TodoValueTypes, InternationalPrefixes
+try:
+    from gammu.data import Connections, MemoryValueTypes, CalendarTypes, CalendarValueTypes, TodoPriorities, TodoValueTypes, InternationalPrefixes
+except ImportError:
+    from gammu.Data import Connections, MemoryValueTypes, CalendarTypes, CalendarValueTypes, TodoPriorities, TodoValueTypes, InternationalPrefixes
 
 
 # When support for sound will be implemented, here should be sounds
