@@ -10,7 +10,7 @@ Config handler wrapper with various defaults, which might be platform dependant.
 __author__ = 'Michal Čihař'
 __email__ = 'michal@cihar.com'
 __license__ = '''
-Copyright © 2003 - 2009 Michal Čihař
+Copyright © 2003 - 2010 Michal Čihař
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License version 2 as published by
@@ -49,7 +49,7 @@ DEFAULT_CONFIG = {
     '/Defaults/Entry-calendar-1': 'START_DATETIME',
     '/Defaults/Entry-calendar-2': 'END_DATETIME',
     '/Wammu/AutoConnect': 'no',
-    '/Gammu/LockDevice': 'no',
+    '/Gammu/LockDevice': False,
     '/Debug/Show': 'no',
     '/Wammu/PhonePrefix': 'Auto',
     '/Wammu/LastPhonePrefix': '',
@@ -64,8 +64,8 @@ DEFAULT_CONFIG = {
     '/Message/Unicode': 'no',
     '/Message/DeliveryReport': 'no',
     '/Message/16bitId': 'yes',
-    '/Gammu/SyncTime': 'yes',
-    '/Gammu/StartInfo': 'no',
+    '/Gammu/SyncTime': True,
+    '/Gammu/StartInfo': True,
     '/Wammu/ConfirmDelete': 'yes',
     '/Wammu/DefaultTime': '09:00:00',
     '/Wammu/DefaultDateOffset': 1,
@@ -76,9 +76,17 @@ DEFAULT_CONFIG = {
     '/Wammu/NameFormat': 'auto',
     '/Wammu/NameFormatString': '%(FirstName)s %(LastName)s (%(Company)s)',
     '/IMAP/Server': '',
+    '/IMAP/Port': '',
     '/IMAP/Login': '',
     '/IMAP/Password': '',
-    '/MesageExport/From': 'Wammu <wammu@wammu.sms>',
+    '/IMAP/RememberPassword': 'no',
+    '/IMAP/UseSSL': 'yes',
+    '/IMAP/OnlyNewMessages': 'yes',
+    '/IMAP/BackupStateRead': 'yes',
+    '/IMAP/BackupStateSent': 'yes',
+    '/IMAP/BackupStateUnread': 'yes',
+    '/IMAP/BackupStateUnsent': 'yes',
+    '/MessageExport/From': 'Wammu <wammu@wammu.sms>',
     '/Gammu/Section': 0,
     '/User/Name': Wammu.OSUtils.GetUserFullName(),
     '/Gammu/Gammurc': os.path.join(u'~', u'.gammurc'),
@@ -151,6 +159,18 @@ class WammuConfig:
             result = self.cfg.ReadFloat(path, 0)
         return result
 
+    def ReadBool(self, path):
+        '''
+        Reads boolean option from configuration.
+        '''
+        try:
+            result = self.cfg.ReadBool(path, DEFAULT_CONFIG[path])
+        except KeyError:
+            # Following line is for debugging purposes only
+            #print 'Warning: no default value for %s' % path
+            result = self.cfg.ReadBool(path, 0)
+        return result
+
     def Write(self, path, value):
         '''
         Writes string option to configuration.
@@ -169,6 +189,12 @@ class WammuConfig:
         '''
         self.cfg.WriteFloat(path, value)
 
+    def WriteBool(self, path, value):
+        '''
+        Writes boolean option to configuration.
+        '''
+        self.cfg.WriteBool(path, value)
+
     def HasEntry(self, path):
         '''
         Checks whether configuration has some entry.
